@@ -2,7 +2,7 @@
 
 #' @export
 
-asym <- function(x,y,method,t=0,tvectors,breakdown=FALSE){
+asym <- function(x,y,method,t=0,tvectors){
   
   if(is.data.frame(tvectors)){
     tvectors <- as.matrix(tvectors)
@@ -23,15 +23,7 @@ asym <- function(x,y,method,t=0,tvectors,breakdown=FALSE){
       y <- as.character(y)
       message("Note: y converted to character")
     }
-    
-    if(breakdown==TRUE){
-      
-      x <- breakdown(x)      
-      y <- breakdown(y)
-      
-    }
-    
-    
+
     if(x %in% rownames(tvectors) && y %in% rownames(tvectors)){
       
       v <- tvectors[x,]
